/*============================================================================
//	apci35w.cs
//
//	Copyright ADTEK SYSTEM SCIENCE Co.,Ltd.
//
//==========================================================================*/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.InteropServices;

namespace SampleA35
{
	/// <summary>
	/// Apci35w ̊Tv̐łB
	/// </summary>
	public class Apci35w
	{
		private int mErrWradll = SUCCESS;	// bp[֐G[

		/*==================*/
		/*	Error Code		*/
		/*==================*/
		public const int	SUCCESS					= 0;	/* Successfully proccessed */
		public const int	ERR_SYSTEM				= 1;	/* Call GetLastError() */
		public const int	ERR_NO_DEVICE			= 2;	/* No card */
		public const int	ERR_IN_USE				= 3;	/* Device is in use */
		public const int	ERR_INVALID_SLOT		= 4;	/* Invalid slot number */
		public const int	ERR_RESOURCE			= 5;	/* Resource exhaustion */
		public const int	ERR_INVALID_ARGUMENT	= 6;	/* Invalid argument */
		public const int	ERR_NO_CREATE			= 7;	/* No created device */
		public const int	ERR_INVALID_CHANNEL		= 8;	/* Invalid channel */
		public const int	ERR_INVALID_RESOLUTION	= 9;	/* Invalid resolution */
		public const int	ERR_TIMEOUT				= 10;	/* Conversion timeout */
		public const int	ERR_WRAPDLL				= -1;	// bp[֐G[

		/*==================*/
		/*	Miscellaneous	*/
		/*==================*/
		public const int	MAX_SLOTS				= 16;	/* Maximum number of slots */

		public const short	SLOT_AUTO				= -1;	/* default search */

		/*==================================*/
		/*	Resource infomation structure	*/
		/*==================================*/
		public const int	MAX_MEM					= 9;	// MAX_MEM_REGISTERS
		public const int	MAX_IO					= 20;	// MAX_IO_PORTS
		public const int	MAX_IRQ					= 7;	// MAX_IRQS
		public const int	MAX_DMA					= 7;	// MAX_DMA_CHANNELS
		public const int	MAX_RSV					= 3;	// MAX_Reserved1

		[StructLayout(LayoutKind.Sequential)]
		public struct Resource
		{
			public int		dwNumMemWindows;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_MEM)]
			public int[]	dwMemBase;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_MEM)]
			public int[]	dwMemLength;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_MEM)]
			public int[]	dwMemAttrib;
			public int		dwNumIOPorts;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_IO)]
			public int[]	dwIOPortBase;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_IO)]
			public int[]	dwIOPortLength;
			public int		dwNumIRQs;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_IRQ)]
			public int[]	dwIRQRegisters;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_IRQ)]
			public int[]	dwIRQAttrib;
			public int		dwNumDMAs;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_DMA)]
			public int[]	dwDMALst;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_DMA)]
			public int[]	dwDMAAttrib;
			[MarshalAs(UnmanagedType.ByValArray,SizeConst = MAX_RSV)]
			public int[]	dwReserved1;
		}

		/*==================================*/
		/*	Sampling parameter structure	*/
		/*==================================*/
		[StructLayout(LayoutKind.Sequential)]
		public struct SampleParams
		{
			public int	dwSamplingChannel;			/* Sampling channel */
			public int	dwResolution;				/* Resolution 8bits/12bits */
		}

		/*==================*/
		/*	API Functions	*/
		/*==================*/
		[DllImport("apci35.dll")]
		public extern static unsafe bool Apci35GetVersion( int* pdwDllVersion, int* pdwDriverVersion );
		[DllImport("apci35.dll")]
		public extern static unsafe bool Apci35Create( short* pwLogSlot );
		[DllImport("apci35.dll")]
		public extern static        bool Apci35Close( short wLogSlot );
		[DllImport("apci35.dll")]
		public extern static        bool Apci35GetResource( short wLogSlot, ref Resource pres );
		[DllImport("apci35.dll")]
		public extern static unsafe bool Apci35GetSwitchValue( short wLogSlot, int* pdwSwitchValue );
		[DllImport("apci35.dll")]
		public extern static unsafe bool Apci35StartSampling( short wLogSlot, ref SampleParams pcpara, short* pwSamplingData );
		[DllImport("apci35.dll")]
		public extern static unsafe bool Apci35InPort( short wLogSlot, Byte* pbInValue );
		[DllImport("apci35.dll")]
		public extern static        bool Apci35OutPort( short wLogSlot, Byte bOutValue );
		[DllImport("apci35.dll")]
		public extern static        int  Apci35GetLastError( short wLogSlot );

		/*****************************************************************************/
		/* 	  aPCI-A35 o[Wԍ擾								 		 */
		/* 	  pdwDllVer DLL	  o[Wԍi[AhX					 */
		/*		  pdwDrvVer Drivero[Wԍi[AhX					 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public unsafe bool GetVersion(int* pdwDllVer, int* pdwDrvVer)
		{
			try {
				return Apci35GetVersion(pdwDllVer, pdwDrvVer);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  aPCI-A35̔Cӂ̃foCX̎gp錾								 */
		/* 	  pwLogSlot	 gpfoCXi[AhX						 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public unsafe bool Create(short* pwLogSlot)
		{
			try {
				return Apci35Create(pwLogSlot);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  aPCI-A35̔Cӂ̃foCX̎gpJ								 */
		/* 	  wLogSlot gpfoCX											 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public bool Close(short wLogSlot)
		{
			try {
				return Apci35Close(wLogSlot);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  wfoCX̃\[X擾									 */
		/* 	  wLogSlot ׂfoCX											 */
		/*		  pres	   \[Xi[\̂̃AhX					 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public bool GetResource(short wLogSlot, ref Resource pres)
		{
			try {
				return Apci35GetResource(wLogSlot, ref pres);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  [^XCb`̒l擾										 */
		/* 	  wLogSlot		 ׂfoCX										 */
		/*		  pdwSwitchValue [^XCb`̒l								 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public unsafe bool GetSwitchValue(short wLogSlot, int* pdwSwitchValue)
		{
			try {
				return Apci35GetSwitchValue(wLogSlot, pdwSwitchValue);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  A/DTvO̎s												 */
		/* 	  wLogSlot		 TvOfoCX							 */
		/*		  pcpara		 TvOp[^								 */
		/*		  pwSamplingData TvOf[^									 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public unsafe bool StartSampling(short wLogSlot, ref SampleParams pcpara, short* pwSamplingData)
		{
			try {
				return Apci35StartSampling(wLogSlot, ref pcpara, pwSamplingData);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  Cӂ̃|[gf[^										 */
		/* 	  wLogSlot	͂foCX										 */
		/*		  pbInValue ̓f[^i[AhX							 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public unsafe bool InPort(short wLogSlot, Byte* pbInValue)
		{
			try {
				return Apci35InPort(wLogSlot, pbInValue);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  Cӂ̃|[gփf[^o										 */
		/* 	  wLogSlot	o͂foCX										 */
		/*		  bOutValue o͂f[^											 */
		/* ߂l  true															 */
		/*		  s false														 */
		/*****************************************************************************/
		public bool OutPort(short wLogSlot, Byte bOutValue)
		{
			try {
				return Apci35OutPort(wLogSlot, bOutValue);
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = ERR_WRAPDLL;	// bp[֐G[
				return false;
			}
		}

		/*****************************************************************************/
		/* 	  aPCI-A35̃G[R[h											 */
		/* 	  wLogSlot	G[foCX								 */
		/* ߂l G[R[h														 */
		/*****************************************************************************/
		public int GetLastError(short wLogSlot)
		{
			try {
				if (mErrWradll == ERR_WRAPDLL) {	// bp[֐G[Ȃ
					mErrWradll = SUCCESS;			// NA
					return ERR_WRAPDLL;
				} else {
					return Apci35GetLastError(wLogSlot);
				}
			}
			catch (Exception e) {
				MessageBox.Show(e.Message, "aPCI-A35 ERROR",
								MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
				mErrWradll = SUCCESS;	// bp[֐G[
				return ERR_WRAPDLL;
			}
		}

	}
};
