/*============================================================================
//	apci35w.h
//
//	Copyright ADTEK SYSTEM SCIENCE Co.,Ltd.
//
//==========================================================================*/
#pragma once

using namespace System;
using namespace System::ComponentModel;
using namespace System::Collections;
using namespace System::Windows::Forms;
using namespace System::Data;
using namespace System::Drawing;
using namespace System::Runtime::InteropServices;

static int mErrWradll;	// bp[֐G[

public class Apci35w
{
public:
	/*==================*/
	/*	Error Code		*/
	/*==================*/
	static const int	SUCCESS					= 0;	/* Successfully proccessed */
	static const int	ERR_SYSTEM				= 1;	/* Call GetLastError() */
	static const int	ERR_NO_DEVICE			= 2;	/* No card */
	static const int	ERR_IN_USE				= 3;	/* Device is in use */
	static const int	ERR_INVALID_SLOT		= 4;	/* Invalid slot number */
	static const int	ERR_RESOURCE			= 5;	/* Resource exhaustion */
	static const int	ERR_INVALID_ARGUMENT	= 6;	/* Invalid argument */
	static const int	ERR_NO_CREATE			= 7;	/* No created device */
	static const int	ERR_INVALID_CHANNEL		= 8;	/* Invalid channel */
	static const int	ERR_INVALID_RESOLUTION	= 9;	/* Invalid resolution */
	static const int	ERR_TIMEOUT				= 10;	/* Conversion timeout */
	static const int	ERR_WRAPDLL				= -1;	// bp[֐G[

	/*==================*/
	/*	Miscellaneous	*/
	/*==================*/
	static const int	MAX_SLOTS				= 16;	/* Maximum number of slots */

	static const short	SLOT_AUTO				= -1;	/* default search */

	/*==================================*/
	/*	Resource infomation structure	*/
	/*==================================*/
	static const int	MAX_MEM					= 9;	// MAX_MEM_REGISTERS
	static const int	MAX_IO					= 20;	// MAX_IO_PORTS
	static const int	MAX_IRQ					= 7;	// MAX_IRQS
	static const int	MAX_DMA					= 7;	// MAX_DMA_CHANNELS
	static const int	MAX_RSV					= 3;	// MAX_Reserved1

	// \[X
	struct Resource {
		int	dwNumMemWindows;
		int dwMemBase[Apci35w::MAX_MEM];
		int dwMemLength[Apci35w::MAX_MEM];
		int dwMemAttrib[Apci35w::MAX_MEM];
		int	dwNumIOPorts;
		int dwIOPortBase[Apci35w::MAX_IO];
		int dwIOPortLength[Apci35w::MAX_IO];
		int dwNumIRQs;
		int dwIRQRegisters[Apci35w::MAX_IRQ];
		int dwIRQAttrib[Apci35w::MAX_IRQ];
		int dwNumDMAs;
		int dwDMALst[Apci35w::MAX_DMA];
		int dwDMAAttrib[Apci35w::MAX_DMA];
		int dwReserved1[Apci35w::MAX_RSV];
	};

	// TvO[h
	struct SampleParams {
		Int32	dwSamplingChannel;			/* Sampling channel */
		Int32	dwResolution;				/* Resolution 8bits/12bits */
	};

	/*==================*/
	/*	API Functions	*/
	/*==================*/
	[DllImport("apci35.dll")]
	static bool Apci35GetVersion( int* pdwDllVersion, int* pdwDriverVersion );
	[DllImport("apci35.dll")]
	static bool Apci35Create( short* pwLogSlot );
	[DllImport("apci35.dll")]
	static bool Apci35Close( short wLogSlot );
	[DllImport("apci35.dll")]
	static bool Apci35GetResource( short wLogSlot, [In][Out] Resource* pres );
	[DllImport("apci35.dll")]
	static bool Apci35GetSwitchValue( short wLogSlot, int* pdwSwitchValue );
	[DllImport("apci35.dll")]
	static bool Apci35StartSampling( short wLogSlot, [In][Out] SampleParams* pcpara, short* pwSamplingData );
	[DllImport("apci35.dll")]
	static bool Apci35InPort( short wLogSlot, Byte* pbInValue );
	[DllImport("apci35.dll")]
	static bool Apci35OutPort( short wLogSlot, Byte bOutValue );
	[DllImport("apci35.dll")]
	static int  Apci35GetLastError( short wLogSlot );

	/*****************************************************************************/
	/* 	  aPCI-A35 o[Wԍ擾								 		 */
	/* 	  pdwDllVer DLL	  o[Wԍi[AhX					 */
	/*		  pdwDrvVer Drivero[Wԍi[AhX					 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool GetVersion(int* pdwDllVer, int* pdwDrvVer)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35GetVersion(pdwDllVer, pdwDrvVer);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  aPCI-A35̔Cӂ̃foCX̎gp錾								 */
	/* 	  pwLogSlot	 gpfoCXi[AhX						 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool Create(short* pwLogSlot)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35Create(pwLogSlot);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  aPCI-A35̔Cӂ̃foCX̎gpJ								 */
	/* 	  wLogSlot gpfoCX											 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool Close(short wLogSlot)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35Close(wLogSlot);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  wfoCX̃\[X擾									 */
	/* 	  wLogSlot ׂfoCX											 */
	/*		  pres	   \[Xi[\̂̃AhX					 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool GetResource(short wLogSlot, [In][Out] Resource* pres)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35GetResource(wLogSlot, pres);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  [^XCb`̒l擾										 */
	/* 	  wLogSlot		 ׂfoCX										 */
	/*		  pdwSwitchValue [^XCb`̒l								 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool GetSwitchValue(short wLogSlot, int* pdwSwitchValue)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35GetSwitchValue(wLogSlot, pdwSwitchValue);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  A/DTvO̎s												 */
	/* 	  wLogSlot		 TvOfoCX							 */
	/*		  pcpara		 TvOp[^								 */
	/*		  pwSamplingData TvOf[^									 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool StartSampling(short wLogSlot, [In][Out] SampleParams* pcpara, short* pwSamplingData)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35StartSampling(wLogSlot, pcpara, pwSamplingData);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  Cӂ̃|[gf[^										 */
	/* 	  wLogSlot	͂foCX										 */
	/*		  pbInValue ̓f[^i[AhX							 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool InPort(short wLogSlot, Byte* pbInValue)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35InPort(wLogSlot, pbInValue);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  Cӂ̃|[gփf[^o										 */
	/* 	  wLogSlot	o͂foCX										 */
	/*		  bOutValue o͂f[^											 */
	/* ߂l  true															 */
	/*		  s false														 */
	/*****************************************************************************/
	static bool OutPort(short wLogSlot, Byte bOutValue)
	{
		mErrWradll = SUCCESS;
		try {
			return Apci35OutPort(wLogSlot, bOutValue);
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = ERR_WRAPDLL;	// bp[֐G[
			return false;
		}
	}

	/*****************************************************************************/
	/* 	  aPCI-A35̃G[R[h											 */
	/* 	  wLogSlot	G[foCX								 */
	/* ߂l G[R[h														 */
	/*****************************************************************************/
	static int GetLastError(short wLogSlot)
	{
		try {
			if (mErrWradll == ERR_WRAPDLL) {	// bp[֐G[Ȃ
				mErrWradll = SUCCESS;			// NA
				return ERR_WRAPDLL;
			} else {
				return Apci35GetLastError(wLogSlot);
			}
		}
		catch (Exception^e) {
			MessageBox::Show(e->Message, "aPCI-A35 ERROR",
								MessageBoxButtons::OK, MessageBoxIcon::Exclamation);
			mErrWradll = SUCCESS;	// bp[֐G[
			return ERR_WRAPDLL;
		}
	}

};
