/************************************************************************/
/*		aPCI-A35 Device Driver for Windows 95/NT						*/
/*																		*/
/*			apci35.h	-	Win32 interface definition					*/
/*			date		-	1998/06/22									*/
/************************************************************************/

#if !defined( APCI35_H )
#define	APCI35_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI35_SUCCESS					0	/* Successfully proccessed */
#define	APCI35_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI35_ERR_NO_DEVICE			2	/* No card */
#define	APCI35_ERR_IN_USE				3	/* Device is in use */
#define	APCI35_ERR_INVALID_SLOT			4	/* Invalid slot number */
#define	APCI35_ERR_RESOURCE				5	/* Resource exhaustion */
#define	APCI35_ERR_INVALID_ARGUMENT		6	/* Invalid argument */
#define	APCI35_ERR_NO_CREATE			7	/* No created device */
#define APCI35_ERR_INVALID_CHANNEL		8	/* Invalid channel */
#define	APCI35_ERR_INVALID_RESOLUTION	9	/* Invalid resolution */
#define	APCI35_ERR_TIMEOUT				10	/* Conversion timeout */

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI35_MAX_SLOTS	16			/* Maximum number of slots */

										/* default search */
#define	APCI35_SLOT_AUTO	( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI35_BOARD_ID		0x9035		/* pci bus device id */
#define	APCI35_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI35_DEVICE_ID	( ( DWORD )APCI35_BOARD_ID\
							| ( ( DWORD )APCI35_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI35_MAX_MEM		9			/* number of memory windows */
#define	APCI35_MAX_IO		20			/* number of i/o windows */
#define	APCI35_MAX_IRQ		7			/* number of irqs */
#define	APCI35_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI35RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI35_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI35_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI35_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI35_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI35_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI35_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI35_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI35_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI35_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI35RESOURCE, *PAPCI35R;

/*==================================*/
/*	Sampling parameter structure	*/
/*==================================*/
typedef struct _APCI35PARA {
	DWORD	dwSamplingChannel;					/* Sampling channel */
	DWORD	dwResolution;						/* Resolution 8bits/12bits */
} APCI35PARA, *PAPCI35P;

#if !defined( APCI35_DRIVER )
#define	APCI35_API

#if !defined( APCI35_DLL )
	#define APCI35LIB_API	extern __declspec( dllimport )
#else
	#define APCI35LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI35LIB_API BOOL	WINAPI	Apci35GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI35LIB_API BOOL	WINAPI	Apci35Create( PWORD pwLogSlot );
APCI35LIB_API BOOL	WINAPI	Apci35Close( WORD wLogSlot );
APCI35LIB_API BOOL	WINAPI	Apci35GetResource( WORD wLogSlot, PAPCI35R pres );
APCI35LIB_API BOOL	WINAPI	Apci35GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI35LIB_API BOOL	WINAPI	Apci35StartSampling( WORD wLogSlot, PAPCI35P pcpara, PWORD pwSamplingData );
APCI35LIB_API BOOL	WINAPI	Apci35InPort( WORD wLogSlot, PBYTE pbInValue );
APCI35LIB_API BOOL	WINAPI	Apci35OutPort( WORD wLogSlot, BYTE bOutValue );
APCI35LIB_API DWORD	WINAPI	Apci35GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI35_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI35_H ) */

/**/